aboutsummaryrefslogtreecommitdiffstats
path: root/device/tun_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'device/tun_test.go')
-rw-r--r--device/tun_test.go18
1 files changed, 9 insertions, 9 deletions
diff --git a/device/tun_test.go b/device/tun_test.go
index fbe4c1d..5614771 100644
--- a/device/tun_test.go
+++ b/device/tun_test.go
@@ -13,27 +13,27 @@ import (
)
// newDummyTUN creates a dummy TUN device with the specified name.
-func newDummyTUN(name string) tun.TUNDevice {
+func newDummyTUN(name string) tun.Device {
return &dummyTUN{
name: name,
packets: make(chan []byte, 100),
- events: make(chan tun.TUNEvent, 10),
+ events: make(chan tun.Event, 10),
}
}
// A dummyTUN is a tun.TUNDevice which is used in unit tests.
type dummyTUN struct {
name string
mtu int
packets chan []byte
- events chan tun.TUNEvent
+ events chan tun.Event
}
-func (d *dummyTUN) Events() chan tun.TUNEvent { return d.events }
-func (*dummyTUN) File() *os.File { return nil }
-func (*dummyTUN) Flush() error { return nil }
-func (d *dummyTUN) MTU() (int, error) { return d.mtu, nil }
-func (d *dummyTUN) Name() (string, error) { return d.name, nil }
+func (d *dummyTUN) Events() chan tun.Event { return d.events }
+func (*dummyTUN) File() *os.File { return nil }
+func (*dummyTUN) Flush() error { return nil }
+func (d *dummyTUN) MTU() (int, error) { return d.mtu, nil }
+func (d *dummyTUN) Name() (string, error) { return d.name, nil }
func (d *dummyTUN) Close() error {
close(d.events)
@@ -13,27 +13,27 @@ import (
}
}
-// A dummyTUN is a tun.TUNDevice which is used in unit tests.
+// A dummyTUN is a tun.Device which is used in unit tests.
type dummyTUN struct {
name string